@@ -1,14 +1,13 @@
-#!/usr/bin/python
-# Convert HTML data to plaintext using Lynx, html2text or a regex
-# Requirements: Either lynx (default) or html2text or simply Python (for regex)
-# This file is part of urlwatch
+# -*- coding: utf-8 -*-
 #
-# Copyright (c) 2009-2011 Thomas Perl <thp.io/about>
+# This file is part of urlwatch (https://thp.io/2008/urlwatch/).
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
+#
 # 1. Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
 # 2. Redistributions in binary form must reproduce the above copyright
@@ -16,7 +15,7 @@
 #    documentation and/or other materials provided with the distribution.
 # 3. The name of the author may not be used to endorse or promote products
 #    derived from this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 # IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 # OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -30,70 +29,91 @@
 
 
 import re
+import os
+import subprocess
+import logging
+
+logger = logging.getLogger(__name__)
+
+
+def html2text(data, method='lynx', options=None):
 
-def html2text(data, method='lynx', utf8=False):
     """
     Convert a string consisting of HTML to plain text
     for easy difference checking.
 
     Method may be one of:
      'lynx' (default) - Use "lynx -dump" for conversion
+                        options: see "lynx -help" output for options that work with "-dump"
      'html2text'      - Use "html2text -nobs" for conversion
+                        options: https://linux.die.net/man/1/html2text
+     'bs4'            - Use Beautiful Soup library to prettify the HTML
+                        options: "parser" only, bs4 supports "lxml", "html5lib", and "html.parser"
+                        http://beautiful-soup-4.readthedocs.io/en/latest/#specifying-the-parser-to-use
      're'             - A simple regex-based HTML tag stripper
-
-    If utf8 is True, the data will be handled as utf-8 by Lynx and
-    html2text (if possible). It seems like only the Debian-provided
-    version of html2text has support for the "-utf8" command line
-    flag, so this might not work on non-Debian systems.
-
-    Dependencies: apt-get install lynx html2text
+     'pyhtml2text'    - Use Python module "html2text"
+                        options: https://github.com/Alir3z4/html2text/blob/master/docs/usage.md#available-options
     """
-    if isinstance(data, unicode):
-        data = data.encode('utf-8')
+    if options is None:
+        options = {}
 
     if method == 're':
         stripped_tags = re.sub(r'<[^>]*>', '', data)
         d = '\n'.join((l.rstrip() for l in stripped_tags.splitlines() if l.strip() != ''))
         return d
 
+    if method == 'pyhtml2text':
+        import html2text
+        parser = html2text.HTML2Text()
+        for k, v in options.items():
+            setattr(parser, k.lower(), v)
+        d = parser.handle(data)
+        return d
+
+    if method == 'bs4':
+        from bs4 import BeautifulSoup
+        parser = options.pop('parser', 'html.parser')
+        soup = BeautifulSoup(data, parser)
+        d = soup.prettify()
+        return d
+
     if method == 'lynx':
-        cmd = ['lynx', '-dump', '-stdin']
-
-        if utf8:
-            cmd.append('-assume_charset=UTF-8')
+        cmd = ['lynx', '-nonumbers', '-dump', '-stdin', '-assume_charset UTF-8', '-display_charset UTF-8']
     elif method == 'html2text':
-        cmd = ['html2text', '-nobs']
-
-        if utf8:
-            cmd.append('-utf8')
+        cmd = ['html2text', '-nobs', '-utf8']
     else:
-        return data
+        raise ValueError('Unknown html2text method: %r' % (method,))
 
-    import subprocess
-    html2text = subprocess.Popen(cmd, stdin=subprocess.PIPE, \
-            stdout=subprocess.PIPE)
-    (stdout, stderr) = html2text.communicate(data)
+    stdout_encoding = 'utf-8'
+
+    for k, v in options.items():
+        cmd.append('-%s %s' % (k, v) if v is True else '-%s' % k)
+
+    logger.debug('Command: %r, stdout encoding: %s', cmd, stdout_encoding)
+
+    env = {}
+    env.update(os.environ)
+    env['LANG'] = 'en_US.utf-8'
+    env['LC_ALL'] = 'en_US.utf-8'
+
+    html2text = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, env=env)
+    stdout, stderr = html2text.communicate(data.encode('utf-8'))
+    stdout = stdout.decode(stdout_encoding)
 
     if method == 'lynx':
         # Lynx translates relative links in the mode we use it to:
         # file://localhost/tmp/[RANDOM STRING]/[RELATIVE LINK]
+
+        # Recent versions of lynx (seen in 2.8.8pre1-1) do not include the
+        # "localhost" in the file:// URLs; see Debian bug 732112
+        stdout = re.sub(r'file://%s/[^/]*/' % (os.environ.get('TMPDIR', '/tmp'),), '', stdout)
+
         # Use the following regular expression to remove the unnecessary
         # parts, so that [RANDOM STRING] (changing on each call) does not
         # expose itself as change on the website (it's a Lynx-related thing
         # Thanks to Evert Meulie for pointing that out
-        stdout = re.sub(r'file://localhost/tmp/[^/]*/', '', stdout)
+        stdout = re.sub(r'file://localhost%s/[^/]*/' % (os.environ.get('TMPDIR', '/tmp'),), '', stdout)
         # Also remove file names like L9816-5928TMP.html
         stdout = re.sub(r'L\d+-\d+TMP.html', '', stdout)
 
-    return stdout
-
-
-if __name__ == '__main__':
-    import sys
-
-    if len(sys.argv) == 2:
-        print html2text(open(sys.argv[1]).read())
-    else:
-        print 'Usage: %s document.html' % (sys.argv[0])
-        sys.exit(1)
-
+    return stdout.strip()
