@@ -1,14 +1,13 @@
-#!/usr/bin/python
-# Convert iCalendar data to plaintext (very basic, don't rely on it :)
-# Requirements: python-vobject (http://vobject.skyhouseconsulting.com/)
-# This file is part of urlwatch
+# -*- coding: utf-8 -*-
 #
-# Copyright (c) 2008-2011 Thomas Perl <thp.io/about>
+# This file is part of urlwatch (https://thp.io/2008/urlwatch/).
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
+#
 # 1. Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
 # 2. Redistributions in binary form must reproduce the above copyright
@@ -16,7 +15,7 @@
 #    documentation and/or other materials provided with the distribution.
 # 3. The name of the author may not be used to endorse or promote products
 #    derived from this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 # IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 # OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
@@ -32,12 +31,12 @@
 def ical2text(ical_string):
     import vobject
     result = []
-    if isinstance(ical_string, unicode):
+    if isinstance(ical_string, str):
         parsedCal = vobject.readOne(ical_string)
     else:
         try:
             parsedCal = vobject.readOne(ical_string)
-        except:
+        except Exception as e:
             parsedCal = vobject.readOne(ical_string.decode('utf-8', 'ignore'))
 
     for event in parsedCal.getChildren():
@@ -60,14 +59,3 @@ def ical2text(ical_string):
             result.append('%s: %s' % (date_str, event.summary.value))
 
     return '\n'.join(result)
-
-
-if __name__ == '__main__':
-    import sys
-
-    if len(sys.argv) == 2:
-        print ical2text(open(sys.argv[1]).read())
-    else:
-        print 'Usage: %s icalendarfile.ics' % (sys.argv[0])
-        sys.exit(1)
-
